@@ -35,7 +35,6 @@
 #include "dmap-connection-private.h"
 #include "dmap-error.h"
 #include "dmap-record-factory.h"
-#include "dmap-marshal.h"
 #include "dmap-structure.h"
 
 #define DMAP_USER_AGENT "iTunes/4.6 (Windows; N)"
@@ -84,12 +83,15 @@ struct DmapConnectionPrivate
 	char *last_error_message;
 };
 
-G_DEFINE_TYPE_WITH_CODE (DmapConnection,
-                         dmap_connection,
-                         G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (DmapConnection));
+G_DEFINE_TYPE_WITH_PRIVATE (DmapConnection,
+                            dmap_connection,
+                            G_TYPE_OBJECT);
 
-#define DMAP_CONNECTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONNECTION, DmapConnectionPrivate))
+static void
+dmap_connection_init (DmapConnection * connection)
+{
+	connection->priv = dmap_connection_get_instance_private(connection);
+}
 
 enum
 {
@@ -192,7 +194,7 @@ _finalize (GObject * object)
 {
 	g_debug ("Finalize");
 
-	g_assert(IS_DMAP_CONNECTION (object));
+	g_assert(DMAP_IS_CONNECTION (object));
 
 	DmapConnection *connection = DMAP_CONNECTION (object);
 	if (NULL == connection->priv) {
@@ -438,7 +440,7 @@ dmap_connection_class_init (DmapConnectionClass * klass)
 					      G_STRUCT_OFFSET
 					      (DmapConnectionClass,
 					       authenticate), NULL, NULL,
-					      dmap_marshal_generated_VOID__STRING_POINTER_POINTER_POINTER_BOOLEAN,
+					      NULL,
 					      G_TYPE_NONE, 5,
 					      G_TYPE_STRING,
 					      SOUP_TYPE_SESSION,
@@ -450,43 +452,37 @@ dmap_connection_class_init (DmapConnectionClass * klass)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DmapConnectionClass,
 					       connecting), NULL, NULL,
-			      dmap_marshal_generated_VOID__ULONG_FLOAT, G_TYPE_NONE, 2,
+			      NULL, G_TYPE_NONE, 2,
 			      G_TYPE_ULONG, G_TYPE_FLOAT);
 	_signals[CONNECTED] =
 		g_signal_new ("connected", G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DmapConnectionClass,
 					       connected), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 	_signals[DISCONNECTED] =
 		g_signal_new ("disconnected",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (DmapConnectionClass,
 					       disconnected), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 	_signals[OPERATION_DONE] =
 		g_signal_new ("operation-done",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_FIRST,
 			      G_STRUCT_OFFSET (DmapConnectionClass,
 					       operation_done), NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+			      NULL, G_TYPE_NONE, 0);
 	_signals[ERROR] =
 		g_signal_new ("error",
 		              G_TYPE_FROM_CLASS (object_class),
 		              G_SIGNAL_RUN_FIRST,
 		              0, NULL, NULL,
-		              g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1,
+		              NULL, G_TYPE_NONE, 1,
 		              G_TYPE_POINTER);
 }
 
-static void
-dmap_connection_init (DmapConnection * connection)
-{
-	connection->priv = DMAP_CONNECTION_GET_PRIVATE (connection);
-}
-
 static void
 _connection_connected (DmapConnection * connection)
 {
@@ -762,7 +758,7 @@ _actual_http_response_handler (DmapResponseData * data)
 					    data->connection);
 		}
 		structure = dmap_structure_parse (response, response_length, &error);
-		if (structure == NULL) {
+		if (error != NULL) {
 			dmap_connection_emit_error(data->connection, error->code,
 			                          "Error parsing %s response: %s\n", message_path,
 			                           error->message);
@@ -1403,7 +1399,7 @@ _handle_logout (DmapConnection * connection, G_GNUC_UNUSED guint status,
 static void
 _finish (DmapConnection * connection)
 {
-	g_assert(IS_DMAP_CONNECTION (connection));
+	g_assert(DMAP_IS_CONNECTION (connection));
 
 	g_debug ("DMAP finish");
 	connection->priv->state = DMAP_DONE;
@@ -1564,7 +1560,7 @@ _do_something (DmapConnection * connection)
 gboolean
 dmap_connection_is_connected (DmapConnection * connection)
 {
-	g_assert(IS_DMAP_CONNECTION (connection));
+	g_assert(DMAP_IS_CONNECTION (connection));
 
 	return connection->priv->is_connected;
 }
@@ -1677,7 +1673,7 @@ dmap_connection_start (DmapConnection * connection,
 {
 	ConnectionResponseData *rdata;
 
-	g_assert(IS_DMAP_CONNECTION (connection));
+	g_assert(DMAP_IS_CONNECTION (connection));
 	g_assert(connection->priv->state == DMAP_GET_INFO);
 
 	g_debug ("Creating new DMAP connection to %s:%d",
@@ -1740,7 +1736,7 @@ dmap_connection_stop(DmapConnection * connection,
 	DmapConnectionPrivate *priv = connection->priv;
 	ConnectionResponseData *rdata;
 
-	g_assert(IS_DMAP_CONNECTION (connection));
+	g_assert(DMAP_IS_CONNECTION (connection));
 
 	g_debug ("Disconnecting");
 
@@ -1884,7 +1880,7 @@ _error_cb(G_GNUC_UNUSED DmapConnection *connection, GError *error,
 } \
 
 START_TEST(_actual_http_response_handler_test) \
-_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("minm\x00\x00\x00\x0dHello, world!",
+_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("minm\x00\x00\x00\x0eHello, world!",
                                     sizeof bytes, DMAP_STATUS_OK);
 END_TEST
 
