@@ -38,7 +38,6 @@
 #include <libsoup/soup-server.h>
 
 #include <libdmapsharing/dmap.h>
-#include <libdmapsharing/dmap-marshal.h>
 #include <libdmapsharing/dmap-structure.h>
 #include <libdmapsharing/dmap-share-private.h>
 
@@ -85,8 +84,6 @@ typedef struct {
 	DmapConnection *connection;
 } DACPRemoteInfo;
 
-#define DMAP_CONTROL_SHARE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONTROL_SHARE, DmapControlSharePrivate))
-
 enum {
 	PROP_0,
 	PROP_LIBRARY_NAME,
@@ -106,10 +103,9 @@ enum {
 
 static guint _signals[LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE_WITH_CODE (DmapControlShare,
-                         dmap_control_share,
-                         DMAP_TYPE_SHARE,
-                         G_ADD_PRIVATE (DmapControlShare));
+G_DEFINE_TYPE_WITH_PRIVATE (DmapControlShare,
+                            dmap_control_share,
+                            DMAP_TYPE_SHARE);
 
 static gchar *
 _get_dbid (void)
@@ -234,8 +230,8 @@ _finalize (GObject * object)
 	G_OBJECT_CLASS (dmap_control_share_parent_class)->finalize (object);
 }
 
-const char *
-dmap_control_share_get_type_of_service (G_GNUC_UNUSED DmapShare * share)
+static const char *
+_get_type_of_service (G_GNUC_UNUSED DmapShare * share)
 {
 	return DACP_TYPE_OF_SERVICE;
 }
@@ -251,7 +247,7 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 	object_class->dispose = _dispose;
 	object_class->finalize = _finalize;
 
-	dmap_class->get_type_of_service = dmap_control_share_get_type_of_service;
+	dmap_class->get_type_of_service = _get_type_of_service;
 	dmap_class->ctrl_int = dmap_control_share_ctrl_int;
 	dmap_class->login = dmap_control_share_login;
 
@@ -288,7 +284,7 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 			      G_STRUCT_OFFSET (DmapControlShareClass, remote_found),
 			      NULL,
 			      NULL,
-			      dmap_marshal_generated_VOID__STRING_STRING,
+			      NULL,
 			      G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 
 	/**
@@ -305,7 +301,7 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 			      G_STRUCT_OFFSET (DmapControlShareClass, remote_lost),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 
 	/**
@@ -323,7 +319,7 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 			      G_STRUCT_OFFSET (DmapControlShareClass, remote_paired),
 			      NULL,
 			      NULL,
-			      dmap_marshal_generated_VOID__STRING_BOOLEAN,
+			      NULL,
 			      G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_BOOLEAN);
 
 	/**
@@ -342,7 +338,7 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 			      G_STRUCT_OFFSET (DmapControlShareClass, lookup_guid),
 			      NULL,
 			      NULL,
-			      dmap_marshal_generated_BOOLEAN__STRING,
+			      NULL,
 			      G_TYPE_BOOLEAN, 1, G_TYPE_STRING);
 
 	/**
@@ -365,14 +361,14 @@ dmap_control_share_class_init (DmapControlShareClass * klass)
 			      G_STRUCT_OFFSET (DmapControlShareClass, add_guid),
 			      NULL,
 			      NULL,
-			      g_cclosure_marshal_VOID__STRING,
+			      NULL,
 			      G_TYPE_NONE, 1, G_TYPE_STRING);
 }
 
 static void
 dmap_control_share_init (DmapControlShare * share)
 {
-	share->priv = DMAP_CONTROL_SHARE_GET_PRIVATE (share);
+	share->priv = dmap_control_share_get_instance_private(share);
 
 	share->priv->current_revision = 2;
 
